.. _references:

References
==========
.. [CP2011a] Chambolle, A and Pock, T. *A First-Order
   Primal-Dual Algorithm for Convex Problems with Applications to
   Imaging*. Journal of Mathematical Imaging and Vision, 40 (2011),
   pp 120-145.

.. [CP2011b] Chambolle, A and Pock, T.
   *Diagonal preconditioning for first order primal-dual algorithms in convex optimization*.
   2011 IEEE International Conference on Computer Vision (ICCV), 2011, pp 1762-1769.

.. [PB2014] Parikh, N, and Boyd, S. *Proximal Algorithms*.
   Foundations and Trends in Optimization, 1 (2014), pp 127-239.

.. [Pre+2007] Press, W H, Teukolsky, S A, Vetterling, W T, and Flannery, B P.
   *Numerical Recipes in C - The Art of Scientific Computing* (Volume 3).
   Cambridge University Press, 2007.

.. [Roc1970] Rockafellar, R. T. *Convex analysis*. Princeton
   University Press, 1970.

.. [Sid+2012] Sidky, E Y, Jorgensen, J H, and Pan, X.
   *Convex optimization problem prototyping for image reconstruction in computed tomography with the Chambolle-Pock algorithm*.
   Physics in Medicine and Biology, 57 (2012), pp 3065-3091.

.. [SW1971] Stein, E, and Weiss, G.
   *Introduction to Fourier Analysis on Euclidean Spaces*.
   Princeton University Press, 1971.
